pub fn parse_region_code(code: &str) -> RegionExpand description
Parse a region code (e.g. “US”, “DE”) into Region. Falls back to
Region::US for unrecognised codes to match the legacy behaviour at
je_generator.rs::parse_region.
pub fn parse_region_code(code: &str) -> RegionParse a region code (e.g. “US”, “DE”) into Region. Falls back to
Region::US for unrecognised codes to match the legacy behaviour at
je_generator.rs::parse_region.