pub enum AnalyticalPhase {
Planning,
Substantive,
FinalReview,
}Expand description
Phase of the audit in which the analytical procedure is applied.
Variants
Planning
Planning phase — used to understand the entity and identify risk areas
Substantive
Substantive phase — used as a substantive procedure to detect material misstatement
FinalReview
Final review phase — used as an overall review at completion