pub enum ActionPlanStatus {
Open,
InProgress,
Implemented,
Overdue,
}Expand description
Status of a management action plan in response to a recommendation.
Variants
Open
Action plan has not yet been started
InProgress
Action plan is in progress
Implemented
Action plan has been fully implemented
Overdue
Action plan has passed its target date without implementation