pub enum IaWorkAssessment {
Reliable,
PartiallyReliable,
Unreliable,
}Expand description
External auditor’s assessment of the reliability of a specific piece of internal audit work.
Variants
Reliable
Work is reliable and can be used without significant modification
PartiallyReliable
Work is partially reliable — some additional procedures required
Unreliable
Work is not reliable — cannot be used by the external auditor