UserEntityControl

Struct UserEntityControl 

pub struct UserEntityControl {
    pub id: String,
    pub soc_report_id: String,
    pub description: String,
    pub mapped_objective: String,
    pub implemented: bool,
    pub operating_effectiveness: ControlEffectiveness,
}
A complementary user entity control (CUEC) mapped to a SOC objective.

User entities are responsible for implementing certain controls to complement the controls at the service organization. These are documented by the user auditor per ISA 402 requirements.

Fields

id: String

Unique identifier

soc_report_id: String

Reference to the SOC report this control relates to

description: String

Description of the user entity control

mapped_objective: String

ID of the SOC control objective this control maps to

implemented: bool

Whether the control has been implemented

operating_effectiveness: ControlEffectiveness

Operating effectiveness assessment

Implementations

Source

impl UserEntityControl

pub fn new( soc_report_id: impl Into<String>, description: impl Into<String>, mapped_objective: impl Into<String>, implemented: bool, operating_effectiveness: ControlEffectiveness, ) -> Self

Create a new user entity control.