CosoPrinciple

Enum CosoPrinciple 

pub enum CosoPrinciple {
Show 17 variants IntegrityAndEthics, BoardOversight, OrganizationalStructure, CommitmentToCompetence, Accountability, ClearObjectives, IdentifyRisks, FraudRisk, ChangeIdentification, ControlActions, TechnologyControls, PoliciesAndProcedures, QualityInformation, InternalCommunication, ExternalCommunication, OngoingMonitoring, DeficiencyEvaluation,
}
COSO 2013 Framework - 17 Principles of Internal Control.

Each principle maps to one of the 5 COSO components:

  • Control Environment: Principles 1-5
  • Risk Assessment: Principles 6-9
  • Control Activities: Principles 10-12
  • Information & Communication: Principles 13-15
  • Monitoring Activities: Principles 16-17

Variants



IntegrityAndEthics

Principle 1: The organization demonstrates a commitment to integrity and ethical values.



BoardOversight

Principle 2: The board of directors demonstrates independence from management and exercises oversight of internal control.



OrganizationalStructure

Principle 3: Management establishes structures, reporting lines, and appropriate authorities and responsibilities.



CommitmentToCompetence

Principle 4: The organization demonstrates a commitment to attract, develop, and retain competent individuals.



Accountability

Principle 5: The organization holds individuals accountable for their internal control responsibilities.



ClearObjectives

Principle 6: The organization specifies objectives with sufficient clarity to enable the identification and assessment of risks.



IdentifyRisks

Principle 7: The organization identifies risks to the achievement of its objectives and analyzes risks as a basis for determining how the risks should be managed.



FraudRisk

Principle 8: The organization considers the potential for fraud in assessing risks to the achievement of objectives.



ChangeIdentification

Principle 9: The organization identifies and assesses changes that could significantly impact the system of internal control.



ControlActions

Principle 10: The organization selects and develops control activities that contribute to the mitigation of risks.



TechnologyControls

Principle 11: The organization selects and develops general control activities over technology to support the achievement of objectives.



PoliciesAndProcedures

Principle 12: The organization deploys control activities through policies that establish what is expected and procedures that put policies into action.



QualityInformation

Principle 13: The organization obtains or generates and uses relevant, quality information to support the functioning of internal control.



InternalCommunication

Principle 14: The organization internally communicates information, including objectives and responsibilities for internal control.



ExternalCommunication

Principle 15: The organization communicates with external parties regarding matters affecting the functioning of internal control.



OngoingMonitoring

Principle 16: The organization selects, develops, and performs ongoing and/or separate evaluations to ascertain whether the components of internal control are present and functioning.



DeficiencyEvaluation

Principle 17: The organization evaluates and communicates internal control deficiencies in a timely manner to those parties responsible for taking corrective action.

Implementations

Source

impl CosoPrinciple

pub fn component(&self) -> CosoComponent

Returns the COSO component that this principle belongs to.

pub fn principle_number(&self) -> u8

Returns the principle number (1-17) in the COSO framework.