pub enum FourFourFiveAnchor {
FirstSundayOf(u8),
LastSaturdayOf(u8),
NearestSaturdayTo(u8),
}Expand description
Anchor point for 4-4-5 fiscal year start.
Variants
FirstSundayOf(u8)
Fiscal year starts on the first Sunday of a month.
LastSaturdayOf(u8)
Fiscal year starts on the last Saturday of a month.
NearestSaturdayTo(u8)
Fiscal year ends on the Saturday nearest to a month end.