pub struct EntityCounts {
pub vendors: usize,
pub customers: usize,
pub employees: usize,
pub materials: usize,
pub fixed_assets: usize,
}Expand description
Counts of master-data entities generated so far.
Used to avoid regenerating master data in subsequent periods and to allocate additional entities if growth is configured.
Fields
vendors: usizeNumber of vendor master records.
customers: usizeNumber of customer master records.
employees: usizeNumber of employee master records.
materials: usizeNumber of material master records.
fixed_assets: usizeNumber of fixed-asset master records.