pub struct EnergyConsumption {
pub id: String,
pub entity_id: String,
pub facility_id: String,
pub period: NaiveDate,
pub energy_source: EnergySourceType,
pub consumption_kwh: Decimal,
pub cost: Decimal,
pub currency: String,
pub is_renewable: bool,
}Expand description
Energy consumption record for a facility in a period.
Fields
id: Stringentity_id: Stringfacility_id: Stringperiod: NaiveDateenergy_source: EnergySourceTypeconsumption_kwh: Decimalcost: Decimalcurrency: Stringis_renewable: boolTrait Implementations
Sourceimpl Clone for EnergyConsumption
impl Clone for EnergyConsumption
Sourcefn clone(&self) -> EnergyConsumption
fn clone(&self) -> EnergyConsumption
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnergyConsumption
impl Debug for EnergyConsumption
Sourceimpl<'de> Deserialize<'de> for EnergyConsumption
impl<'de> Deserialize<'de> for EnergyConsumption
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for EnergyConsumption
impl Serialize for EnergyConsumption
Sourceimpl ToNodeProperties for EnergyConsumption
impl ToNodeProperties for EnergyConsumption
Sourcefn node_type_name(&self) -> &'static str
fn node_type_name(&self) -> &'static str
Entity type name (snake_case), e.g.
"uncertain_tax_position".Sourcefn node_type_code(&self) -> u16
fn node_type_code(&self) -> u16
Numeric entity type code for registry, e.g.
416.Sourcefn to_node_properties(&self) -> HashMap<String, GraphPropertyValue>
fn to_node_properties(&self) -> HashMap<String, GraphPropertyValue>
Convert all fields to a property map with camelCase keys.