pub struct FraudTriangle {
pub pressure: PressureType,
pub opportunities: Vec<OpportunityFactor>,
pub rationalization: Rationalization,
}Expand description
Fraud Triangle components (Pressure, Opportunity, Rationalization).
The fraud triangle is a model for explaining the factors that cause someone to commit occupational fraud.
Fields
pressure: PressureTypePressure or incentive to commit fraud.
opportunities: Vec<OpportunityFactor>Opportunity factors that enable fraud.
rationalization: RationalizationRationalization used to justify the fraud.
Implementations
Sourceimpl FraudTriangle
impl FraudTriangle
Sourcepub fn new(
pressure: PressureType,
opportunities: Vec<OpportunityFactor>,
rationalization: Rationalization,
) -> Self
pub fn new( pressure: PressureType, opportunities: Vec<OpportunityFactor>, rationalization: Rationalization, ) -> Self
Creates a new fraud triangle.
Sourcepub fn risk_score(&self) -> f64
pub fn risk_score(&self) -> f64
Returns a risk score based on the fraud triangle components.