pub struct FxRateTable {
pub base_currency: String,
/* private fields */
}Expand description
Collection of FX rates with lookup functionality.
Fields
base_currency: StringBase currency for the rate table.
Implementations
Sourceimpl FxRateTable
impl FxRateTable
Sourcepub fn new(base_currency: &str) -> Self
pub fn new(base_currency: &str) -> Self
Creates a new FX rate table with the specified base currency.
Sourcepub fn get_rate(
&self,
from_currency: &str,
to_currency: &str,
rate_type: &RateType,
date: NaiveDate,
) -> Option<&FxRate>
pub fn get_rate( &self, from_currency: &str, to_currency: &str, rate_type: &RateType, date: NaiveDate, ) -> Option<&FxRate>
Gets a rate for the currency pair, type, and date.
Sourcepub fn get_closing_rate(
&self,
from_currency: &str,
to_currency: &str,
date: NaiveDate,
) -> Option<&FxRate>
pub fn get_closing_rate( &self, from_currency: &str, to_currency: &str, date: NaiveDate, ) -> Option<&FxRate>
Gets the closing rate for a currency pair on a date.
Sourcepub fn get_average_rate(
&self,
from_currency: &str,
to_currency: &str,
date: NaiveDate,
) -> Option<&FxRate>
pub fn get_average_rate( &self, from_currency: &str, to_currency: &str, date: NaiveDate, ) -> Option<&FxRate>
Gets the average rate for a currency pair on a date.
Sourcepub fn get_spot_rate(
&self,
from_currency: &str,
to_currency: &str,
date: NaiveDate,
) -> Option<&FxRate>
pub fn get_spot_rate( &self, from_currency: &str, to_currency: &str, date: NaiveDate, ) -> Option<&FxRate>
Gets the spot rate for a currency pair on a date.
Sourcepub fn convert(
&self,
amount: Decimal,
from_currency: &str,
to_currency: &str,
rate_type: &RateType,
date: NaiveDate,
) -> Option<Decimal>
pub fn convert( &self, amount: Decimal, from_currency: &str, to_currency: &str, rate_type: &RateType, date: NaiveDate, ) -> Option<Decimal>
Converts an amount using the appropriate rate.