pub struct MaterialPool {
pub materials: Vec<Material>,
/* private fields */
}Expand description
Pool of materials for transaction generation.
Fields
materials: Vec<Material>All materials
Implementations
Sourceimpl MaterialPool
impl MaterialPool
Sourcepub fn from_materials(materials: Vec<Material>) -> Self
pub fn from_materials(materials: Vec<Material>) -> Self
Create a material pool from a vector of materials.
This is the preferred way to create a pool from generated master data, ensuring JEs reference real entities.
Sourcepub fn add_material(&mut self, material: Material)
pub fn add_material(&mut self, material: Material)
Add a material to the pool.
Sourcepub fn random_material(&self, rng: &mut impl Rng) -> Option<&Material>
pub fn random_material(&self, rng: &mut impl Rng) -> Option<&Material>
Get a random material.
Sourcepub fn random_material_of_type(
&self,
material_type: MaterialType,
rng: &mut impl Rng,
) -> Option<&Material>
pub fn random_material_of_type( &self, material_type: MaterialType, rng: &mut impl Rng, ) -> Option<&Material>
Get a random material of a specific type.
Sourcepub fn get_by_abc(&self, classification: char) -> Vec<&Material>
pub fn get_by_abc(&self, classification: char) -> Vec<&Material>
Get materials by ABC classification.
Sourcepub fn rebuild_indices(&mut self)
pub fn rebuild_indices(&mut self)
Rebuild indices after deserialization.