pub struct VendorPool {
pub vendors: Vec<Vendor>,
/* private fields */
}Expand description
Pool of vendors for transaction generation.
Fields
vendors: Vec<Vendor>All vendors
Implementations
Sourceimpl VendorPool
impl VendorPool
Sourcepub fn from_vendors(vendors: Vec<Vendor>) -> Self
pub fn from_vendors(vendors: Vec<Vendor>) -> Self
Create a vendor pool from a vector of vendors.
This is the preferred way to create a pool from generated master data, ensuring JEs reference real entities.
Sourcepub fn add_vendor(&mut self, vendor: Vendor)
pub fn add_vendor(&mut self, vendor: Vendor)
Add a vendor to the pool.
Sourcepub fn random_vendor(&self, rng: &mut impl Rng) -> Option<&Vendor>
pub fn random_vendor(&self, rng: &mut impl Rng) -> Option<&Vendor>
Get a random vendor.
Sourcepub fn random_vendor_of_type(
&self,
vendor_type: VendorType,
rng: &mut impl Rng,
) -> Option<&Vendor>
pub fn random_vendor_of_type( &self, vendor_type: VendorType, rng: &mut impl Rng, ) -> Option<&Vendor>
Get a random vendor of a specific type.
Sourcepub fn rebuild_index(&mut self)
pub fn rebuild_index(&mut self)
Rebuild the type index (call after deserialization).