pub struct JeFingerprint {
pub je_id: String,
pub l1_fingerprint: u64,
pub l2_fingerprint: u64,
pub bs_only: bool,
pub is_only: bool,
pub line_count: usize,
}Expand description
Per-JE fingerprint + flags (kept for the per-JE CSV; not serialized in the summary report to keep it bounded).
Fields
je_id: Stringl1_fingerprint: u64l2_fingerprint: u64bs_only: boolis_only: boolline_count: usizeTrait Implementations
Sourceimpl Clone for JeFingerprint
impl Clone for JeFingerprint
Sourcefn clone(&self) -> JeFingerprint
fn clone(&self) -> JeFingerprint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JeFingerprint
impl Debug for JeFingerprint
Sourceimpl PartialEq for JeFingerprint
impl PartialEq for JeFingerprint
Sourcefn eq(&self, other: &JeFingerprint) -> bool
fn eq(&self, other: &JeFingerprint) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for JeFingerprint