pub struct NamePool {
pub first_names_male: Vec<String>,
pub first_names_female: Vec<String>,
pub last_names: Vec<String>,
pub culture: NameCulture,
}Expand description
Pool of names for a specific culture.
Fields
first_names_male: Vec<String>Male first names
first_names_female: Vec<String>Female first names
last_names: Vec<String>Last names / family names
culture: NameCultureThe culture this pool represents
Implementations
Sourceimpl NamePool
impl NamePool
Sourcepub fn western_us() -> Self
pub fn western_us() -> Self
Create a Western US name pool.
Sourcepub fn for_culture(culture: NameCulture) -> Self
pub fn for_culture(culture: NameCulture) -> Self
Get a name pool for a specific culture.
Sourcepub fn validate(&self) -> Result<(), String>
pub fn validate(&self) -> Result<(), String>
Validate that the name pool has at least one entry in each list.
Returns Err if any name list is empty, preventing panics during generation.
Sourcepub fn generate_name(&self, rng: &mut impl Rng) -> PersonName
pub fn generate_name(&self, rng: &mut impl Rng) -> PersonName
Generate a random name from this pool.
Sourcepub fn from_culture_config(config: &CultureConfig, culture: NameCulture) -> Self
pub fn from_culture_config(config: &CultureConfig, culture: NameCulture) -> Self
Create a NamePool from a CultureConfig loaded from a country pack.