Shared generator utilities.
Functions
- sample_
decimal_ range - Sample a Decimal in a range using the RNG.
- seeded_
rng - Create a seeded RNG for a generator, with an optional discriminator for sub-generators.
- weighted_
select - Select from weighted options. Weights don’t need to sum to 1.0.