DataReliability

Enum DataReliability 

pub enum DataReliability {
    High,
    Medium,
    Low,
}
Reliability of the underlying data used to compute the relationship.

Variants



High

Data comes from a routine, fully-automated, previously-audited source.



Medium

Data is semi-automated or subject to internal review but not audit.



Low

Data is manually compiled or unverified.