pub struct ServiceOrganization {
pub id: String,
pub name: String,
pub service_type: ServiceType,
pub entities_served: Vec<String>,
}Expand description
A service organization used by one or more audited entities.
Fields
id: StringUnique identifier
name: StringName of the service organization
service_type: ServiceTypeType of service provided
entities_served: Vec<String>Entity codes of user entities served by this organization
Implementations