pub struct UserEntityControl {
pub id: String,
pub soc_report_id: String,
pub description: String,
pub mapped_objective: String,
pub implemented: bool,
pub operating_effectiveness: ControlEffectiveness,
}Expand description
A complementary user entity control (CUEC) mapped to a SOC objective.
User entities are responsible for implementing certain controls to complement the controls at the service organization. These are documented by the user auditor per ISA 402 requirements.
Fields
id: StringUnique identifier
soc_report_id: StringReference to the SOC report this control relates to
description: StringDescription of the user entity control
mapped_objective: StringID of the SOC control objective this control maps to
implemented: boolWhether the control has been implemented
operating_effectiveness: ControlEffectivenessOperating effectiveness assessment
Implementations