Graph property mapping trait and types for node export.
Provides a ToNodeProperties trait that each model struct implements
to map typed Rust fields to camelCase graph properties expected by
downstream consumers (e.g. AssureTwin).
Enums
- Graph
Property Value - Property value for graph node export.
Traits
- ToNode
Properties - Trait for converting typed model structs to graph node property maps.
Functions
- camel_
to_ snake - Convert a CamelCase or PascalCase string to snake_case.